@@ -44,7 +44,7 @@ gyrus_admin_acl_set_tree_view (GyrusAdmin *admin, const gchar *mailbox_path);
 gboolean
 gyrus_admin_mailbox_get_quota (GyrusAdmin *admin, const gchar *mailbox_path,
 			       gint *quota_limit, gint *quota_used,
-			       gchar **message)
+			       gchar **error)
 {
 	gchar *msg, **parts;
 	msg = g_strdup_printf (". getquota \"%s\"\n", mailbox_path);
@@ -52,7 +52,7 @@ gyrus_admin_mailbox_get_quota (GyrusAdmin *admin, const gchar *mailbox_path,
 	g_free (msg);
 	GyrusImapStatus status;
 
-	*message = NULL;
+	*error = NULL;
 	
 	status = gyrus_admin_listen_channel (admin, &msg, NULL);
 	if (status == GYRUS_IMAP_STATUS_BYE) {
@@ -73,9 +73,9 @@ gyrus_admin_mailbox_get_quota (GyrusAdmin *admin, const gchar *mailbox_path,
 		*quota_used = -1;
 		*quota_limit = -1;
 		if (strcmp (parts [2], "Quota") == 0)
-			*message = g_strdup (_("Quota does not exists"));
+			*error = g_strdup (_("Quota does not exists"));
 		else if (strcmp (parts [2], "Permission") == 0)
-			*message = g_strdup (_("Permission denied"));
+			*error = g_strdup (_("Permission denied"));
 	}
 	g_free (msg);	
 	g_strfreev (parts);
@@ -231,7 +231,7 @@ gyrus_admin_mailbox_on_button_quota_apply_clicked (GtkButton *button,
 	if (gyrus_admin_mailbox_set_quota (admin, mailbox_path, new_quota)) {
 		gtk_entry_set_text (GTK_ENTRY (admin->priv->entry_quota_new),
 				    "");
-		tokens = g_strsplit (mailbox_path, ".", 3);
+		tokens = g_strsplit (mailbox_path, gyrus_admin_get_separator_char (admin), 3);
 		gyrus_admin_mailbox_show_info (admin, tokens[1], mailbox_path);
 		g_strfreev (tokens);
 	}
@@ -280,10 +280,10 @@ gyrus_admin_mailbox_exists (GyrusAdmin *admin,
 }
 
 gboolean 
-gyrus_admin_mailbox_name_is_valid (const gchar *mailbox)
+gyrus_admin_mailbox_name_is_valid (GyrusAdmin *admin, const gchar *mailbox)
 {
 	return (/*!g_strrstr (mailbox, " ") &&*/
-		!g_strrstr (mailbox, "."));
+		!g_strrstr (mailbox, gyrus_admin_get_separator_char (admin)));
 }
 
 
@@ -320,7 +320,7 @@ gyrus_admin_mailbox_new (GyrusAdmin *admin, const gchar *mailbox,
 	GIOError ioerror = G_IO_ERROR_NONE;
 	GyrusImapStatus status;
 	
-	if (!gyrus_admin_mailbox_name_is_valid (mailbox)) {
+	if (!gyrus_admin_mailbox_name_is_valid (admin, mailbox)) {
 		*error = g_strdup_printf (_("'%s' is not a valid "
 					    "mailbox name. Please try a different one."),
 					  mailbox);
@@ -335,7 +335,8 @@ gyrus_admin_mailbox_new (GyrusAdmin *admin, const gchar *mailbox,
 		return FALSE;
 	}
 	
-	gchar *new_mailbox = g_strconcat (path, ".", mailbox, NULL);
+	gchar *new_mailbox = g_strconcat (path, gyrus_admin_get_separator_char (admin), 
+					  mailbox, NULL);
 
 	if (gyrus_admin_mailbox_exists (admin, new_mailbox)) {
 		*error = g_strdup_printf (_("Mailbox '%s' already exists. "
@@ -378,9 +379,7 @@ gyrus_admin_get_submailboxes (GyrusAdmin *admin,
 {
 	GList *list = NULL;
 	gchar *c_mailbox;
-
-	gint offset = strlen ("* LIST () \".\" \"");
-	
+		
 	gchar *msg = g_strdup_printf (". list \"%s\" *\n", mailbox);
 	gyrus_admin_write_channel (admin, msg);
 	g_free (msg);
@@ -394,10 +393,7 @@ gyrus_admin_get_submailboxes (GyrusAdmin *admin,
 		* LIST () "." "user.mymailbox"\n\0
 		
 		*/
-		
-		c_mailbox = g_strndup (msg + offset,
-				       strlen (msg + offset) - 3);
-
+		c_mailbox = gyrus_admin_get_mailbox_from_list_message (msg);
 		list = g_list_prepend (list, c_mailbox);
 		g_free (msg);
 	}
