@@ -33,6 +33,8 @@
 #include "gyrus-admin-mailbox.h"
 #include "gyrus-admin-acl.h"
 
+/* #define DEBUG_PLAIN_CHANNEL*/
+
 static void gyrus_admin_class_init (GyrusAdminClass *class);
 static void gyrus_admin_init (GyrusAdmin *admin);
 static void gyrus_admin_finalize (GObject *object);
@@ -244,19 +246,63 @@ gyrus_admin_users_tree_model_new (void)
 	GtkTreeModel *model;
 
 	model = GTK_TREE_MODEL(	gtk_tree_store_new (COL_USERS_NUMBER, 
-						    GDK_TYPE_PIXBUF, 
+						    G_TYPE_STRING, 
 						    G_TYPE_STRING,
 						    G_TYPE_STRING));
 	
 	return model;
 }
 
+gchar *
+gyrus_admin_get_mailbox_from_list_message (gchar *msg)
+{
+	int k, large;
+	gchar *mb_name;
+	gchar *iterator = msg;
+	for (k = 0; k < 4; k++) {
+			while (*iterator != ' ')
+				iterator++;
+			iterator ++;
+	}
+	/* to remove the "\n\0" */
+	large = strlen (iterator) - 2;
+	
+	if (*iterator == '\"') {
+		iterator ++;
+		large -= 2; /* remove the '"' */
+	}
+	mb_name = g_strndup (iterator, large);
+
+	return mb_name;
+}
+
+void
+gyrus_admin_set_separator_char_auto (GyrusAdmin *admin)
+{
+	gchar **str_v;
+	gchar *msg = g_strdup (". list \"\" \"\"\n");
+	GIOError error = G_IO_ERROR_NONE;
+
+	error = gyrus_admin_write_channel (admin, msg);
+	g_free (msg);
+
+	gyrus_admin_listen_channel (admin, &msg, NULL);
+	str_v = g_strsplit (msg, " ", -1);
+	g_free (msg);
+
+	gyrus_admin_listen_channel (admin, &msg, NULL);
+
+	g_free (admin->priv->session->sep_char);
+	admin->priv->session->sep_char = g_strdup_printf ("%c", str_v[3][1]);
+
+	g_free (msg);
+	g_strfreev (str_v);
+}
+
 void
 gyrus_admin_get_users_list (GyrusAdmin *admin)
 {
-	GdkPixbuf *pixbuf_folder;
 	GtkTreeStore *store;
-	gchar *path_folder;
 	gchar *msg;
 	gchar **current_mailbox;
 	GIOError error = G_IO_ERROR_NONE;
@@ -266,41 +312,24 @@ gyrus_admin_get_users_list (GyrusAdmin *admin)
         gint n_users;
         GtkTreeViewColumn *column;
 	GyrusImapStatus status;
-	
-	path_folder = g_strdup_printf ("%s%c%s", GYRUS_PIXMAPS_DIR,
-				       G_DIR_SEPARATOR, "folder.png");
-	pixbuf_folder = gdk_pixbuf_new_from_file (path_folder, NULL);
-	g_free (path_folder);
+	gchar *mb_name;
 	
 	store =	GTK_TREE_STORE (gtk_tree_view_get_model
 				(admin->priv->treeview_users));
 	gtk_tree_store_clear (store);
 
-	msg = g_strdup (". list user. *\n");
+	msg = g_strdup (". list * *\n");
 	error = gyrus_admin_write_channel (admin, msg);
 	g_free (msg);
 	g_return_if_fail (error == G_IO_ERROR_NONE);
-	
+
 	while ((status = gyrus_admin_listen_channel (admin, &msg, NULL)) ==
 	       GYRUS_IMAP_STATUS_LIST) {
-		int k, large;
-		gchar *iterator = msg;
-		for (k = 0; k < 4; k++) {
-			while (*iterator != ' ')
-				iterator++;
-			iterator ++;
-		}
-		/* to remove the "\n\0" */
-		large = strlen (iterator) - 2;
-		
-		if (*iterator == '\"') {
-			iterator ++;
-			large -= 2; /* remove the '"' */
-		}
-		gchar *mb_name = g_strndup (iterator, large);
-/*		g_print ("%s\n", mb_name); */
+		mb_name = gyrus_admin_get_mailbox_from_list_message (msg);
 
-		current_mailbox = g_strsplit (mb_name, ".", -1);
+		current_mailbox = g_strsplit (mb_name, 
+					      gyrus_admin_get_separator_char (admin), 
+					      -1);
 
 		depth = 0;
 		is_valid = FALSE;
@@ -343,7 +372,7 @@ gyrus_admin_get_users_list (GyrusAdmin *admin)
 
 		if (is_valid) {
 			gtk_tree_store_set (store, &iter_child,
-					    COL_USERS_ICON, pixbuf_folder,
+					    COL_USERS_ICON, GTK_STOCK_DIRECTORY,
 					    COL_USERS_MAILBOX, current_mailbox [depth],
 					    COL_USERS_MAILBOX_PATH, mb_name,
 					    -1);
@@ -387,10 +416,14 @@ gyrus_admin_initialize_users_tree_view (GyrusAdmin *admin)
 
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	gtk_tree_view_column_pack_start (column, renderer, FALSE);
+	g_object_set (G_OBJECT (renderer),
+	              "stock-size", GTK_ICON_SIZE_LARGE_TOOLBAR,
+	              NULL);
+	
 	gtk_tree_view_column_set_attributes (column, renderer,
-					     "pixbuf", COL_USERS_ICON,
-					     NULL);
-
+	                                     "stock-id", COL_USERS_ICON,
+	                                     NULL);
+	
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start (column, renderer, TRUE);
 	gtk_tree_view_column_set_attributes (column, renderer,
@@ -571,26 +604,48 @@ GyrusImapStatus
 gyrus_admin_listen_channel (GyrusAdmin *admin, gchar **message, gint *msg_len)
 {
 	gchar buffer[BUFFER_SIZE];
-	gint bytes_read;
-	gchar **tokens;
-	GIOError error = G_IO_ERROR_NONE;
-	GyrusImapStatus imap_status = GYRUS_IMAP_STATUS_OK;
+	guint bytes_read;
+	gchar **tokens = NULL;
+	GIOError error;
 	
-	error = gnet_io_channel_readline (admin->priv->iochannel,
-					  buffer, BUFFER_SIZE,
-					  &bytes_read);
-	if (error != G_IO_ERROR_NONE) {
-		g_warning ("%i", error);
-		return TRUE;
-	}
-	
-/*	g_print ("readed:  %s", buffer); */
-	
-	*message = g_strdup (buffer);
-	tokens = g_strsplit (*message, " ", 0);
-	if (msg_len != NULL)
-		*msg_len = bytes_read;
+	*message = NULL;
 
+	GyrusImapStatus imap_status;
+
+	/* Trick to ignore the ALERTs */
+
+	do {
+		g_free (*message);
+		g_strfreev (tokens);
+
+		error = G_IO_ERROR_NONE;
+		imap_status = GYRUS_IMAP_STATUS_OK;
+		
+		error = gnet_io_channel_readline (admin->priv->iochannel,
+						  buffer, BUFFER_SIZE,
+						  &bytes_read);
+		if (error != G_IO_ERROR_NONE) {
+			g_warning ("%i", error);
+			return TRUE;
+		}
+		
+#ifdef DEBUG_PLAIN_CHANNEL
+		g_print ("readed:  %s", buffer);
+#endif
+		*message = g_strdup (buffer);
+		tokens = g_strsplit (*message, " ", 0);
+		if (msg_len != NULL)
+			*msg_len = bytes_read;
+		
+		/* Displays a popup with the alert. As the user is not supposed 
+		   to decide if displays or not the alert, we do it always */
+		if (g_ascii_strcasecmp (tokens [2], "[ALERT]") == 0) {
+			gyrus_common_show_message (NULL, GTK_MESSAGE_INFO, 
+						   *message + strlen ("* OK "));
+
+		}
+	} while (g_ascii_strcasecmp (tokens [2], "[ALERT]") == 0);
+	
 	if (g_ascii_strcasecmp (tokens[1], "BYE") == 0)
 		imap_status = GYRUS_IMAP_STATUS_BYE;
 	else if (g_ascii_strcasecmp (tokens[1], "OK") == 0)
@@ -610,13 +665,15 @@ gyrus_admin_listen_channel (GyrusAdmin *admin, gchar **message, gint *msg_len)
 GIOError
 gyrus_admin_write_channel (GyrusAdmin *admin, gchar *message)
 {
-	gint msg_len, bytes_written;
+	guint msg_len, bytes_written;
 	GIOError error = G_IO_ERROR_NONE;
 
 	msg_len = g_utf8_strlen (message, -1);
 	error = gnet_io_channel_writen (admin->priv->iochannel, message,
 					msg_len, &bytes_written);
-/* 	g_print ("written: %s", message);  */
+#ifdef DEBUG_PLAIN_CHANNEL
+ 	g_print ("written: %s", message); 
+#endif
 	return error;
 }
 
@@ -646,8 +703,15 @@ gyrus_admin_logged_out (GyrusAdmin *admin)
 	GtkTreeStore *store;
 	GtkTreeViewColumn *column;
 	
+	GtkWidget *btn_image;
+	
 	gtk_button_set_label (GTK_BUTTON (admin->priv->button_connect),
-			      GTK_STOCK_JUMP_TO);
+			      _("_Connect"));
+
+	btn_image = gtk_image_new_from_stock (GTK_STOCK_CONNECT, GTK_ICON_SIZE_BUTTON);
+	gtk_button_set_image (GTK_BUTTON (admin->priv->button_connect),
+			      btn_image);
+
 	store = GTK_TREE_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (admin->priv->treeview_users)));
 	gtk_tree_store_clear (store);
 	column = gtk_tree_view_get_column(GTK_TREE_VIEW (admin->priv->treeview_users), 0);
@@ -729,6 +793,9 @@ gyrus_admin_post_login (GyrusAdmin *admin)
 						   (admin->priv->parent_app),
 						   TRUE);
 	}
+	if (strcmp (gyrus_admin_get_separator_char (admin), "auto") == 0)
+		gyrus_admin_set_separator_char_auto (admin);
+	
 	gyrus_admin_get_users_list (admin);
 }
 
@@ -774,8 +841,12 @@ gyrus_admin_pre_login (GyrusAdmin *admin)
 				/* do something useful here */
 			}
 			else {
+				GtkWidget *btn_image;
 				gtk_button_set_label (GTK_BUTTON (admin->priv->button_connect),
-						      GTK_STOCK_STOP);
+						      _("_Disconnect"));
+				btn_image = gtk_image_new_from_stock (GTK_STOCK_DISCONNECT, GTK_ICON_SIZE_BUTTON);
+				gtk_button_set_image (GTK_BUTTON (admin->priv->button_connect),
+						      btn_image);
 				gyrus_admin_post_login (admin);
 				/* correctly logged in */
 				keep_asking = FALSE;
@@ -805,8 +876,10 @@ gyrus_admin_select_foreach_func (GtkTreeModel *model, GtkTreePath *path,
 		gtk_tree_view_expand_to_path (admin->priv->treeview_users, path);
 
 		gtk_tree_selection_select_iter (selection, iter);
+		g_free (this_mailbox);
 		return TRUE;
 	}
+	g_free (this_mailbox);
 	return FALSE;
 }
 
@@ -905,6 +978,15 @@ gyrus_admin_get_current_passwd (GyrusAdmin *admin)
 	return admin->priv->session->passwd;
 }
 
+const gchar*
+gyrus_admin_get_separator_char (GyrusAdmin *admin)
+{
+	g_return_val_if_fail (GYRUS_IS_ADMIN (admin), NULL);
+	g_return_val_if_fail (admin->priv && admin->priv->session, NULL);
+
+	return admin->priv->session->sep_char;
+}
+
 gboolean
 gyrus_admin_has_current_acl_access (GyrusAdmin *admin)
 {
@@ -941,6 +1023,7 @@ gyrus_admin_load_session_info (GyrusAdmin *admin, GyrusSession *session)
 	admin->priv->session->user = g_strdup (session->user);
 	admin->priv->session->name = g_strdup (session->name);
 	admin->priv->session->port = session->port;
+	admin->priv->session->sep_char = g_strdup (session->sep_char);
 
 	/* set the interface */
 	gtk_label_set_label (GTK_LABEL (admin->priv->label_host),
@@ -1043,7 +1126,7 @@ gyrus_admin_on_users_selection_changed (GtkTreeSelection *selection,
 				    -1);
 
 		gchar **tokens;
-		tokens = g_strsplit (mailbox_path, ".", 3);
+		tokens = g_strsplit (mailbox_path, gyrus_admin_get_separator_char (admin), 3);
 		gyrus_admin_mailbox_show_info (admin, tokens[1],
 					       mailbox_path);
 		g_strfreev (tokens);
@@ -1193,7 +1276,10 @@ gyrus_admin_on_acl_identifier_edited (GtkCellRendererText *cellrenderertext,
 	GyrusAdmin *admin = GYRUS_ADMIN (user_data);
 	
 	model = gtk_tree_view_get_model (admin->priv->treeview_acl);
-	gtk_tree_model_get_iter_from_string (model, &iter, path_string);
+	if (!gtk_tree_model_get_iter_from_string (model, &iter, path_string)) {
+		return;
+	}
+
 	gtk_tree_model_get (model, &iter,
 			    COL_ACL_IDENTIFIER, &oldname,
 			    -1);
